@@ -226,6 +226,7 @@ int scanmanager(const struct optstruct *opt)
 	if(tolower(ptr[strlen(ptr) - 1]) == 'm') {
 	    cpy = calloc(strlen(ptr), 1);
 	    strncpy(cpy, ptr, strlen(ptr) - 1);
+	    cpy[strlen(ptr)-1]='\0';
 	    limits.maxscansize = atoi(cpy) * 1024 * 1024;
 	    free(cpy);
 	} else
@@ -239,6 +240,7 @@ int scanmanager(const struct optstruct *opt)
 	if(tolower(ptr[strlen(ptr) - 1]) == 'm') {
 	    cpy = calloc(strlen(ptr), 1);
 	    strncpy(cpy, ptr, strlen(ptr) - 1);
+	    cpy[strlen(ptr)-1]='\0';
 	    limits.maxfilesize = atoi(cpy) * 1024 * 1024;
 	    free(cpy);
 	} else
@@ -431,6 +433,7 @@ static int clamav_unpack(const char *prog, const char **args, const char *tmpdir
 	if(tolower(ptr[strlen(ptr) - 1]) == 'm') { /* megabytes */
 	    cpy = calloc(strlen(ptr), 1);
 	    strncpy(cpy, ptr, strlen(ptr) - 1);
+	    cpy[strlen(ptr)-1]='\0';
 	    maxscansize = atoi(cpy) * 1024;
 	    free(cpy);
 	} else /* default - kilobytes */
@@ -949,7 +952,7 @@ static int scandenied(const char *filename, struct cl_engine *engine, const stru
 
 int scanfile(const char *filename, struct cl_engine *engine, const struct passwd *user, const struct optstruct *opt, const struct cl_limits *limits, unsigned int options)
 {
-	int ret, included, printclean = 1;
+	int ret = 0, included, printclean = 1;
 	const struct optnode *optnode;
 	char *argument;
 #ifdef C_LINUX
@@ -1046,7 +1049,6 @@ int scanfile(const char *filename, struct cl_engine *engine, const struct passwd
 
 	/* in other case try to continue with external archivers */
 	options &= ~CL_SCAN_ARCHIVE; /* and disable decompression for the checkfile() below */
-	printclean = 0;
     }
 
     if((cli_strbcasestr(filename, ".zip") && opt_check(opt, "unzip"))
