@@ -1,5 +1,7 @@
 /*
- *  Copyright (C) 2002 - 2005 Tomasz Kojm <tkojm@clamav.net>
+ *  Copyright (C) 2007-2008 Sourcefire, Inc.
+ *
+ *  Authors: Tomasz Kojm, Nigel Horne, Török Edvin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -23,6 +25,12 @@
 
 #include "cltypes.h"
 
+#ifdef HAVE_STRCASESTR
+#define cli_strcasestr strcasestr
+#else
+const char *cli_strcasestr(const char *haystack, const char *needle);
+#endif
+
 int cli_strbcasestr(const char *haystack, const char *needle);
 int cli_chomp(char *string);
 char *cli_strtok(const char *line, int field, const char *delim);
@@ -35,4 +43,5 @@ char *cli_strtokbuf(const char *input, int fieldno, const char *delim, char *out
 const char *cli_memstr(const char *haystack, int hs, const char *needle, int ns);
 char *cli_strrcpy(char *dest, const char *source);
 void cli_strtokenize(char *buffer, const char delim, const size_t token_count, const char **tokens);
+int cli_isnumber(const char *str);
 #endif
