@@ -28,9 +28,14 @@
 
 int mdprintf(int desc, const char *str, ...);
 
+#ifdef __GNUC__
+int logg(const char *str, ...)      __attribute__((format(printf, 1, 2)));
+#else
 int logg(const char *str, ...);
+#endif
+
 void logg_close(void);
-extern short int logg_verbose, logg_lock, logg_time;
+extern short int logg_verbose, logg_nowarn, logg_lock, logg_time;
 extern unsigned int logg_size;
 extern const char *logg_file;
 
@@ -39,7 +44,12 @@ extern short logg_syslog;
 int logg_facility(const char *name);
 #endif
 
+#ifdef __GNUC__
+void mprintf(const char *str, ...) __attribute__((format(printf, 1, 2)));
+#else
 void mprintf(const char *str, ...);
-extern short int mprintf_disabled, mprintf_verbose, mprintf_quiet, mprintf_stdout;
+#endif
+
+extern short int mprintf_disabled, mprintf_verbose, mprintf_quiet, mprintf_nowarn, mprintf_stdout;
 
 #endif
